==> MALDIquant_0.4.tar.gz: MALDIquant/man/intensityMatrix-functions.Rd <==
\name{intensityMatrix}
\alias{intensityMatrix}
\title{
Converts a list MassObject objects into a matrix.
}
\description{
This function converts a \code{\link{list}} of 
\code{\linkS4class{AbstractMassObject}} objects into a \code{\link{matrix}}.
}
\usage{
intensityMatrix(l, replaceNaBy=0) 
}
\arguments{
    \item{l}{
        \code{list} of \code{\linkS4class{AbstractMassObject}} objects.
    }
    \item{replaceNaBy}{
       replaces all missing data (\code{NA}) by \code{replaceNaBy} given value.
       To preserve all \code{NA} choose \code{replaceNaBy=NULL}. 
    }
}
\value{
Returns a \code{\link{matrix}} containing intensities of all
\code{\linkS4class{AbstractMassObject}} objects of \code{l}.
The \code{\link{matrix}} has \code{length(l)} rows 
(one row for each sample) and \code{length(unique(mass))} columns.
}
\details{
The column names of the returned \code{\link{matrix}} store the mass values.
}
\references{
See website: \url{http://strimmerlab.org/software/maldiquant/}
}
\author{
Sebastian Gibb
}
\seealso{
\code{\linkS4class{AbstractMassObject}},
}
\examples{
## load library
library("MALDIquant");

## create example MassPeaks objects
p <- list();

p[[1]] <- createMassPeaks(mass=1:4,
                          intensity=11:14,
                          metaData=list(name="test mass peaks 1"));
p[[2]] <- createMassPeaks(mass=2:5,
                          intensity=22:25,
                          metaData=list(name="test mass peaks 2"));

## converts MassPeaks objects into a matrix 
intensityMatrix(p);

## converts MassPeaks objects into a matrix (preserve NAs)
intensityMatrix(p, replaceNaBy=NULL);
}

==> MALDIquant_1.0.tar.gz: MALDIquant/man/intensityMatrix-functions.Rd <==
\name{intensityMatrix}
\alias{intensityMatrix}
\title{
Converts a list MassObject objects into a matrix.
}
\description{
This function converts a \code{\link{list}} of 
\code{\linkS4class{AbstractMassObject}} objects into a \code{\link{matrix}}.
}
\usage{
intensityMatrix(l, replaceNaBy=0) 
}
\arguments{
    \item{l}{
        \code{list} of \code{\linkS4class{AbstractMassObject}} objects.
    }
    \item{replaceNaBy}{
       replaces all missing data (\code{NA}) by \code{replaceNaBy} given value.
       To preserve all \code{NA} choose \code{replaceNaBy=NULL}. 
    }
}
\value{
Returns a \code{\link{matrix}} containing intensities of all
\code{\linkS4class{AbstractMassObject}} objects of \code{l}.
The \code{\link{matrix}} has \code{length(l)} rows 
(one row for each sample) and \code{length(unique(mass))} columns.
}
\details{
The column names of the returned \code{\link{matrix}} store the mass values.
}
\references{
See website: \url{http://strimmerlab.org/software/maldiquant/}
}
\author{
Sebastian Gibb
}
\seealso{
\code{\linkS4class{AbstractMassObject}},
}
\examples{
## load library
library("MALDIquant");

## create example MassPeaks objects
p <- list(createMassPeaks(mass=1:4,
                          intensity=11:14,
                          metaData=list(name="test mass peaks 1")),
          createMassPeaks(mass=2:5,
                          intensity=22:25,
                          metaData=list(name="test mass peaks 2")));

## converts MassPeaks objects into a matrix 
intensityMatrix(p);

## converts MassPeaks objects into a matrix (preserve NAs)
intensityMatrix(p, replaceNaBy=NULL);
}
\keyword{methods}
